==> 0.6.3rc1.zip: dmdirc-client/src/com/dmdirc/interfaces/NotificationListener.java <==
/*
 * Copyright (c) 2006-2010 Chris Smith, Shane Mc Cormack, Gregory Holmes
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.interfaces;

import com.dmdirc.ui.interfaces.Window;

import java.awt.Color;
import java.util.EventListener;

/**
 * Defines the methods that should be implemented by classes which wish to
 * receive information about notification changes.
 *
 * @author Chris
 */
public interface NotificationListener extends EventListener {

    /**
     * Called when the notification colour has been changed.
     *
     * @param window The window whose notification has changed
     * @param colour The new colour of the notification
     */
    void notificationSet(final Window window, final Color colour);

    /**
     * Called when a notification has been cleared.
     *
     * @param window The window whose notification has been cleared
     */
    void notificationCleared(final Window window);
}

==> 0.6.6b1.zip: dmdirc-client/src/com/dmdirc/interfaces/NotificationListener.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.interfaces;

import com.dmdirc.FrameContainer;

import java.awt.Color;
import java.util.EventListener;

/**
 * Defines the methods that should be implemented by classes which wish to
 * receive information about notification changes.
 */
public interface NotificationListener extends EventListener {

    /**
     * Called when the notification colour has been changed.
     *
     * @param window The window whose notification has changed
     * @param colour The new colour of the notification
     */
    void notificationSet(final FrameContainer window, final Color colour);

    /**
     * Called when a notification has been cleared.
     *
     * @param window The window whose notification has been cleared
     */
    void notificationCleared(final FrameContainer window);
}
